@@ -4,7 +4,7 @@ Based on input network and given GPS trajectory data, the map-matching program
 of Matching2Route aims to find most likely route in terms of node sequence in
 the underlying network, with the following data flow chart.
 
-The code is adopted and modified from 
+The code is adopted and modified from
 https://github.com/asu-trans-ai-lab/MapMatching4GMNS
 """
 
@@ -30,13 +30,23 @@ else:
     raise Exception('Please build the shared library compatible to your OS\
                     using source files in engine_cpp!')
 
-start = time.time()
+
 _cdll = ctypes.cdll.LoadLibrary(_dll_file)
-
+_cdll.MapMatching4GMNS.argtypes = [ctypes.c_int]
 agent_compu = _cdll.MapMatching4GMNS
-agent_compu.restype = ctypes.c_double
-agent = agent_compu()
-end = time.time()
 
-print('MapMatching4GMNS time cost: %.6f seconds' % (end-start))
-print("The output data agent.csv is generated!")
+
+def _optimal_MapMatching4GMNS_CAPI(mode):
+    _cdll.MapMatching4GMNS(mode)
+
+
+'''Two modes:
+    modes 0: reading trace.csv, then automaticically generate input_agent.csv and output agent.csv
+    model 1: reading input_agent.csv, then output agent.csv and link_performance.csv
+'''
+if __name__ == "__main__":
+    start = time.time()
+    _optimal_MapMatching4GMNS_CAPI(0)
+    end = time.time()
+    print('MapMatching4GMNS time cost: %.6f seconds' % (end - start))
+    print("The output data is generated!")
